from ..test_comma_corrector import TestCommaCorrector


class TestGdzie(TestCommaCorrector):
    def test_gdzie(self):
        sentences = [
            "Wiem, gdzie jesteś.",
            "Byłem w kraju, gdzie panują dziwne zwyczaje.",
            "Powiedz mi, gdzie się ukrywasz."
        ]

        self.assertSentences(sentences)
    
    def test_gdzie_pocz(self):
        sentences = [
            "Gdzie dwóch się bije, tam trzeci korzysta."
        ]

        self.assertSentences(sentences)
    
    def test_gdzie_wtr(self):
        sentences = [
            "Tam, gdzie się znalazł, było pusto i cicho.",
            "Stąd, gdzie stałam, nie było nic widać."
        ]

        self.assertSentences(sentences)
    
    def test_gdzie_join(self):
        sentences = [
            "Pojechał na wieś, tam gdzie się urodził.",
            "Pojechał tam, gdzie się urodził."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestTylko(TestCommaCorrector):
    def test_tylko(self):
        sentences = [
            "Nic nie mówił, tylko spojrzał na mnie.",
            "Nie uczyła się, tylko poszła spać."
        ]

        self.assertSentences(sentences)

    def test_tylko_part(self):
        sentences = [
            "Kupiłam tylko masło i mąkę.",
            "Mówię o tym tylko tobie."
        ]

        self.assertSentences(sentences)
    
    def test_tylko_że(self):
        sentences = [
            "Ta książka jest bardzo ciekawa, tylko że za długa.",
            "Dzisiaj jest bardzo ciepło, tylko że wieje chłodny wiatr.",
            "Był niezwykle zdolny, tylko że bardzo leniwy."
        ]

        self.assertSentences(sentences)


import unittest

from aaki.comma_corrector.comma_corrector import CommaCorrector

class TestCommaCorrector(unittest.TestCase):
    def setUp(self) -> None:
        self.corrector = CommaCorrector()

    def assertSentences(self, sentences: list[str]) -> None:
        no_commas_sentences = [sentence.replace(',', '') for sentence in sentences]

        self.corrector.sentences = no_commas_sentences
        corrected_sentences = self.corrector.run()

        for sentence, corrected_sentence in zip(sentences, corrected_sentences):
            with self.subTest(sentence=sentence, corrected_sentence=corrected_sentence):
                self.assertEqual(corrected_sentence, sentence)



from ..test_comma_corrector import TestCommaCorrector


class TestA(TestCommaCorrector):
    def test_a(self):
        sentences = [
            "Zdecydowaliśmy się kupić mieszkanie, a nie dom.",
            "Pojechał samochodem, a nie autobusem.",
            "Damian czeka na ciebie od 10 minut, a ty ciągle wybierasz ubranie.",
            "Wiem, że zajmował się hodowlą węży, skorpionów, pająków, a nawet patyczaków."
        ]

        self.assertSentences(sentences)

    def test_a_także(self):
        sentences = [
            "Latem zwiedziłam Włochy, Hiszpanię i Francję, a także Turcję.",
            "Odpowiedzialność za to spoczywa na uczniach, a także ich rodzicach.",
            "Chciał spędzić ten czas aktywnie, a także odpocząć."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestIż(TestCommaCorrector):
    def test_iż(self):
        sentences = [
            "Zapomniałam, iż mieliśmy się spotkać.",
            "Obiecuję, iż zrobię to dla ciebie."
        ]

        self.assertSentences(sentences)

    def test_mimo_iż(self):
        sentences = [
            "Mimo iż wstałam dziś wcześniej niż zwykle, spóźniłam się do pracy.",
        ]

        self.assertSentences(sentences)

    def test_mimo_iż_wtr(self):
        sentences = [
            "Ta książka, mimo iż ma ciekawą fabułę, nie zachwyciła mnie szczególnie."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestWraz(TestCommaCorrector):
    def test_wraz(self):
        sentences = [
            "Wybraliśmy się wraz z Markiem do kina.",
            "Zostali zaproszeni wraz z dziećmi."
        ]

        self.assertSentences(sentences)
    
    def test_wraz_wtr(self):
        sentences = [
            "Ta sytuacja staje się dziś, wraz z towarzyszącymi jej okolicznościami, niezwykle trudna.",
            "Ta kobieta, wraz ze swoją córką, zapukała wczoraj do naszych drzwi."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestI(TestCommaCorrector):
    def test_i_conj(self):
        sentences = [
            "Dostałam od niego książkę i kwiaty.",
            "Kup jajka, ser i wędlinę.",
            "Lubię psy i koty."
        ]

        self.assertSentences(sentences)

    def test_i_wspl(self):
        sentences = [
            "Lubię słuchać muzyki i czytać książki.",
            "Codziennie chodzę na siłownię i ćwiczę w domu.",
            "Ona tylko ciągle narzeka i narzeka."
        ]

        self.assertSentences(sentences)

    def test_i_powt(self):
        sentences = [
            "Lubię jabłka i gruszki, i jeszcze śliwki.",
            "Latem zwiedziłam i Francję, i Holandię.",
            "I słońce świeciło, i padał deszcz.",
        ]

        self.assertSentences(sentences)

    def test_i_powt_not_rown(self):
        sentences = [
            "Byłem w kinie i spotkałem tam Piotrka i Marcina.",
            "Dotknęłam klamki i nacisnęłam ją szybko i mocno."
        ]

        self.assertSentences(sentences)

    def test_i_wtr(self):
        sentences = [
            "Znam ją od dawna, i to bardzo dobrze.",
            "Chodzę na siłownię, i to codziennie.",
            "Nie pójdę tam, i koniec."
        ]

        self.assertSentences(sentences)

    def test_i_zam_podrz(self):
        sentences = [
            "Lubię oglądać filmy, które trzymają w napięciu, i słuchać muzyki, która mnie relaksuje.",
            "Zdecyduj w końcu, co robimy, i zacznijmy działać."
        ]

        self.assertSentences(sentences)

    def test_i_cons_conj(self):
        sentences = [
            "Nie spałem dziś w nocy, i jestem bardzo zmęczony.",
            "Ta wieża jest bardzo wysoka, i nie każdy na nią wejdzie."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestJakby(TestCommaCorrector):
    def test_jakby(self):
        sentences = [
            "Przyjechałby do ciebie, jakby miał na to czas.",
            "Wygląda, jakby spał."
        ]

        self.assertSentences(sentences)

    def test_jakby_pocz(self):
        sentences = [
            "Jakby mógł, na pewno by to zrobił.",
            "Jakby to znalazła, to by wam oddała."
        ]

        self.assertSentences(sentences)

    def test_jakby_wtr(self):
        sentences = [
            "Nagle usłyszał coś, jakby grzmot, co przerwało panującą wokół ciszę.",
            "Przyszedł, jakby na zawołanie, kiedy akurat miałam do niego dzwonić."
        ]

        self.assertSentences(sentences)

    def test_jakby_wpro(self):
        sentences = [
            "Usłyszał jakby grzmot.",
            "Dzień wydawał się jakby pogodniejszy."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestBowiem(TestCommaCorrector):
    def test_bowiem(self):
        sentences = [
            "Nie przyszedł dziś do szkoły, bowiem zachorował.",
            "Nie była w stanie tego udowodnić, bowiem brakowało jej argumentów."
        ]

        self.assertSentences(sentences)

    def test_bowiem_srod(self):
        sentences = [
            "Nie zrobiłam zakupów, zapomniałam bowiem zabrać ze sobą portfel.",
            "Rząd podjął radykalne kroki, tego bowiem oczekiwali obywatele."
        ]

        self.assertSentences(sentences)

    def test_bowiem_poprz(self):
        sentences = [
            "Był on bowiem wielokrotnie poruszany w naszym gronie.",
            "Obawiałam się bowiem, że mogłaby być niebezpieczna."
        ]

        self.assertSentences(sentences)




def check_aby(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if token_prev.text == "tak":
        result["insert"] = True
        result["insert_pos"] = -1
    if token.pos_ == 'CCONJ':
        pass
    elif token.pos_ == 'PART' or token.pos_ == 'SCONJ':
        result["insert"] = True

    
    return result


def check_czy(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if token.pos_ == 'CCONJ':
        pass
    elif token.pos_ == 'PART' and token_prev.pos_ != 'CCONJ' and token_prev.pos_ != 'PART':
        result["insert"] = True
    elif occured:
        result["insert"] = True
    return result


def check_lub(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if occured:
        result["insert"] = True
    elif token.pos_ == 'CCONJ':
        pass

    result['occured'] = True

    return result


def check_oraz(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if occured:
        result["insert"] = True
    elif token.pos_ == 'CCONJ':
        pass

    result['occured'] = True
    return result

# podrzedne zdania dodac
def check_jak(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # zaimek wprowadzający zdanie/wypowiedzenie podrzędne
    # wyrażenie wprowadzające porównanie o charakterze dopowiedzenia
    # wprowadza ono wyliczenie lub wyszczególnienie
    # zarówno, jak; równie, jak; tak, jak i; tak, jak

    return result


def check_że(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if token_prev.pos_ == 'CCONJ':
        pass
    elif token_prev.pos_ == 'PART' or (token_prev.pos_ == 'ADV' and token_prev.dep_ == 'mark'):
        # if previous token is at the beginning of the sentence
        if token_prev.i != 0:
            result["insert"] = True
            result["insert_pos"] = -1
    else:
        result["insert"] = True
    return result


def check_a(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if token.pos_ == 'CCONJ' and token_prev.pos_ != 'PART':
        pass
    elif token.pos_ == 'PART' and token_prev.pos_ != 'CCONJ' and token_prev.pos_ != 'PART':
        result["insert"] = True
    return result

# podrzedne zdania
def check_niż(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # spójnik wprowadza zdanie podrzędne
    # spójnik wprowadza równoważnik zdania
    # Nie stawiamy: spójnik występuje przed członem porównawczym w zdaniu pojedynczym

    return result


def check_ale(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}
    if token.pos_ == 'NOUN':
        result["insert"] = False

    return result

#kontekst (dopowiedzenie)
def check_albo(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if occured:
        result["insert"] = True

    return result

# zrobione
def check_lecz(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result

def check_ponieważ(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    # zasada dotycząca stawiania przecinka po zdaniu składowym, gdy ponieważ stoi na początku na początku zdania złożonego

    return result


def check_więc(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}
    if token.pos_ == 'PART':
        result["insert_pos"] = False
    elif token_prev.text == 'a':
        result["insert_pos"] = -1
    
    return result

#wtrącenia
def check_czyli(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result

#współdzilene zdania
# spójnik wynikowy
def check_i(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if occured:
        result["insert"] = True
    return result

# do zredagowania
def check_bądź(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # jeżeli occured to wstaw przecinek
    if occured:
        result["insert"] = True

    return result

#odmiany która/którego/itd.
def check_który(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}
    if token_prev.text == 'w' or token_prev.text == 'a':
        result["insert_pos"] = -1

    return result


def check_bo(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result

#nie kumam
def check_ani(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    if occured:
        result["insert"] = True
    return result


def check_żeby(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result

#zdanie podrzędne + pełne wyrażenia
def check_gdy(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}
    return result

#współrzędne/pojedynce
def check_natomiast(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result

#wtrącenia
def check_zanim(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result

#kontekst wyrażenia
def check_zatem(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}
    return result

#wtrącenia
def check_gdzie(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}
    if token_prev.text == 'tam':
        result["insert_pos"] = -1

    return result

#wtraćenia
def check_kiedy(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result

#wtrącenia
def check_by(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result


def check_aż(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}
    if token.pos_ == 'PART':
        result["insert"] = False

    return result


def check_to(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # spójnik - chyba git - sprawdza, czy jest jednym z dwóch rodzajów spójnika
    if token.pos_ == 'CCONJ' or token.pos_ == 'SCONJ':
        result["insert"] = True

    return result


def check_jednak(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}
    
    # spójnik
    if token.pos_ == 'CCONJ' or token.pos_ == 'SCONJ':
        result["insert"] = True
    # nie stawiamy przed partykułą
    if token.pos_ == 'PART':
        result["insert"] = False

    return result


def check_iż(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    result["insert"] = True

    return result


def check_gdyż(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    result["insert"] = True

    return result


def check_także(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # przed "a także"
    if token_prev.text == 'a':
        result["insert_pos"] = -1
        result["insert"] = True

    return result


def check_tylko(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    # dla partykuły "tylko" nie wstawiamy przecinka
    if token.pos_ == "PART":
        result["insert"] = False

    return result

# XD powodzenia
def check_nawet(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    return result


def check_chociaż(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # spójnik
    if token.pos_ == 'CCONJ' or token.pos_ == 'SCONJ':
        result["insert"] = True
    # nie stawiamy przed partykułą
    if token.pos_ == 'PART':
        result["insert"] = False

    return result

# zdania składowe, podrzędne i takie tam
def check_jakby(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    return result


def check_skoro(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    # dodatkowe zasady dla:
    ## pisane na początku zdania
    ## pisane w środku zdania

    return result

# zdanie pojedyncze
def check_bowiem(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    # dodatkowe zasady dla:
    ## przecinek przed całym wprowadzeniem
    ## jeśli zdanie pojedyncze to brak przecinka

    return result


def check_stąd(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # spójnik
    if token.pos_ == 'CCONJ' or token.pos_ == 'SCONJ':
        result["insert"] = True


    return result


def check_dopóki(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    # dodatkowe zasady dla:
    ## jeśli na początku zdania
    ## jako składniki połączeń dopóki...,dopóty...; dopóki...,póty...; dopóty...,dopóki...

    return result


def check_choć(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # spójnik
    if token.pos_ == 'CCONJ' or token.pos_ == 'SCONJ':
        result["insert"] = True
    # nie stawiamy przed partykułą
    if token.pos_ == 'PART':
        result["insert"] = False

    return result


def check_dlatego(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result


def check_co(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    # co jest przed orzeczeniem
    if token_prev.pos_ == 'VERB':
        result["insert"] = True

    # dodać zasady dla:
    ## wprowadza zdanie składowe

    return result

# Zdania składowe złożone, wystepuje razem z zaimkiem
def check_w(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    return result


# zasadniczo nie stawia się przed nim przecinka, chyba że wprowadza wtrącenie
def check_wraz(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}


    return result

# zasadniczo nie stawia się przed nim przecinka, chyba że wprowadza wtrącenie lub określa przyczynę
def check_jako(token, token_prev, occured=False):
    result = {"insert": False, "insert_pos": 0, "occured": occured}

    return result

# jeśli wystepuje na początku zdania złożonego, oddzielamy przecinkiem zdanie składowe
def check_jeśli(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result

# jeśli wystepuje na początku zdania złożonego, oddzielamy przecinkiem zdanie składowe
def check_jeżeli(token, token_prev, occured=False):
    result = {"insert": True, "insert_pos": 0, "occured": occured}

    return result



from ..test_comma_corrector import TestCommaCorrector


class TestPonieważ(TestCommaCorrector):
    def test_ponieważ(self):
        sentences = [
            "Nie mogę teraz rozmawiać, ponieważ jestem bardzo zajęty.",
            "Wróciliśmy dziś wcześniej do domu, ponieważ pogoda nie sprzyjała spacerom."
        ]
    
        self.assertSentences(sentences)
    
    def test_ponieważ_pocz(self):
        sentences = [
            "Ponieważ jestem bardzo zmęczona, muszę położyć się dziś wcześnie spać.",
            "Ponieważ musiałem wyjechać, nie byłem wczoraj w pracy."
        ]
    
        self.assertSentences(sentences)
    
    def test_ponieważ_wtr(self):
        sentences = [
            "Dzisiejsze zebranie, ponieważ było bardzo ważne, przedłużyło się o godzinę.",
            "Gatunek ten, ponieważ jest zagrożony, powinno się chronić szczególnie."
        ]
    
        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestNawet(TestCommaCorrector):
    def test_nawet(self):
        sentences = [
            "Przyszła i nawet się nie odezwała.",
            "Nie zostawiła po sobie nawet jednego śladu."
        ]

        self.assertSentences(sentences)

    def test_nawet_konkr(self):
        sentences = [
            "U nas jest zimno, nawet latem.",
            "Zawsze jej towarzyszył, nawet w chwilach największego zagrożenia.",
            "Dalej tam pracowałem, nawet awansowałem.",
        ]

        self.assertSentences(sentences)

    def test_nawet_srod(self):
        sentences = [
            "Jego książki były dobre, nawet świetne, ale nie zgodził się na ich publikację.",
            "Zrezygnowała ze wszystkiego, nawet z najdrobniejszych przyjemności, aby im pomóc."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestWięc(TestCommaCorrector):
    def test_więc_cons_conj(self):
        sentences = [
            "Cały dzień pracowałem, więc teraz jestem zmęczony.",
            "Od rana padał deszcz, więc nie pojechaliśmy na wycieczkę."
        ]

        self.assertSentences(sentences)
    
    def test_więc_enum(self):
        sentences = [
            "Na miejscu stawili się wszyscy, a więc dyrektor, nauczyciele i uczniowie.",
            "Umówiłem się z nim na dwudziestą, więc za godzinę.",
            "Było tak, jak się spodziewałam, a więc autobus nie przyjechał na czas, a ja spóźniłam się do szkoły."
        ]

        self.assertSentences(sentences)
    
    def test_więc_part(self):
        sentences = [
            "Do widzenia więc!",
            "No więc słucham.",
            "A więc to twoja sprawka."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestJak(TestCommaCorrector):
    def test_jak(self):
        sentences = [
            "Powiem Ci, jak to zrobiłem.",
            "Nie wiem, jak ty, ale spróbowałbym użyć wkrętarki.",
            "W dobrej grze, jak w dobrym filmie, akcja toczy się wartko.",
            "Szybki jak błyskawica.",
            "Marta bardzo lubi owoce tropikalne, takie jak ananasy, banany, brzoskwinie i pomarańcze.",
            "Był równie zmęczony, jak zadowolony.",
            "Adam był tak samo szybki jak Dawid.",
            "Daniel postąpił tak, jak doradziła mu Marta.",
            "Ich oczom ukazał się wysoki dom z zielonym dachem, taki sam jak opisywała go Agnieszka."
        ]

        self.assertSentences(sentences)

    def test_podobnie_jak(self):
        sentences = [
            "Ona ubrała się podobnie jak ja.",
            "Zrób to podobnie jak oni."
        ]

        self.assertSentences(sentences)

    def test_podobnie_jak_wtr(self):
        sentences = [
            "Dzisiaj i wczoraj, podobnie jak dwa dni temu, padał deszcz.",
            "Zawsze robisz mi na złość, podobnie jak twoja siostra."
        ]

        self.assertSentences(sentences)
    
    def test_jak_również(self):
        sentences = [
            "Lubię filmy przygodowe, obyczajowe, jak również sensacyjne.",
            "W konkursie mogą wziąć udział zawodowi pisarze, jak również amatorzy."
        ]

        self.assertSentences(sentences)
    
    def test_taki_jak(self):
        sentences = [
            "Człowiek taki jak ty nie powinien zabierać głosu w tej sprawie.",
            "Jesteś taka nieśmiała jak twoja siostra."
        ]

        self.assertSentences(sentences)
    
    def test_jak_i(self):
        sentences = [
            "Martwił mnie jej stan zdrowia, jak i to, że nie wiedziałem, co nastąpi potem.",
            "Suka, jak i szczenięta, wymagały opieki weterynarza."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestInne(TestCommaCorrector):
    def test_poza_tym(self):
        sentences = [
            "Ugotowałam obiad, poza tym zrobiłam deser.",
            "Nie lubię go, poza tym drażni mnie jego stosunek do pewnych spraw.",
            "Umiem grać na gitarze, pianinie i flecie, poza tym trochę na skrzypcach."
        ]

        self.assertSentences(sentences)

    def test_dzięki_temu(self):
        sentences = [
            "Na dworzec dotarłem o szesnastej, dzięki temu zdążyłem na pociąg.",
            "Lekcje odrobiłam zaraz po przyjściu ze szkoły, dzięki temu mam wolny wieczór."
        ]

        self.assertSentences(sentences)
    
    def test_dzięki_temu_rzecz_cel(self):
        sentences = [
            "Zdałam ten egzamin dzięki twojej pomocy.",
            "Odniosła sukces dzięki odwadze."
        ]

        self.assertSentences(sentences)
    
    def test_dzięki_temu_pocz(self):
        sentences = [
            "Dzięki temu nauczycielowi polubiłam fizykę.",
            "Dzięki twojemu zaangażowaniu nasza firma odniosła sukces."
        ]

        self.assertSentences(sentences)
    
    def test_co_więcej(self):
        sentences = [
            "Nie sądziłam, że mnie to spotka, co więcej, myślałam, że to wręcz nierealne.",
            "Moja babcia ma ponad osiemdziesiąt lat, ale dalej cieszy się dobrym zdrowiem. Co więcej, wciąż jeździ na rowerze.",
            "Bardzo ją polubiłem, co więcej, ja się w niej zakochałem!"
        ]

        self.assertSentences(sentences)


from .comma_corrector import CommaCorrector
from spacy import Language, tokens


class CommaTester:
    """
    Tester for single sentence punctuation.
    Takes correct sentence as input,
    transforms it to sentence without commas
    and checks if checker returns correct result.
    """

    def __init__(self, sentences: list[str] = []):
        self._corrector: CommaCorrector = CommaCorrector()
        self._sentences: list[str] = sentences

    @property
    def sentences(self) -> str:
        return self._sentences

    @sentences.setter
    def sentences(self, sentences: str) -> None:
        self._sentences = sentences

    def _rate_sentence(self, corrected_doc: Language, sentences_doc: Language) -> dict[str, int]:
        """
        Rates correctness of corrected sentence.
        """

        # create index for both documents
        sentences_pos: int = 0
        corrected_pos: int = 0

        # create dict for points
        points: dir[str, int] = {"correct": 0, "incorrect": 0, "missing": 0}

        # iterate through both documents
        while sentences_pos < len(sentences_doc) and corrected_pos < len(corrected_doc):
            # get tokens
            sentences_token: tokens.token.Token = sentences_doc[sentences_pos]
            corrected_token: tokens.token.Token = corrected_doc[corrected_pos]

            # if both tokens are commas, add point to correct
            if sentences_token.text == ',' and corrected_token.text == ',':
                points["correct"] += 1
            # if token in sentences is comma and token in corrected is not, add point to missing
            elif sentences_token.text == ',' and corrected_token.text != ',':
                points["missing"] += 1
                corrected_pos -= 1
            # if token in sentences is not comma and token in corrected is, add point to incorrect
            elif sentences_token.text != ',' and corrected_token.text == ',':
                points["incorrect"] += 1
                sentences_pos -= 1

            # increment both indexes
            sentences_pos += 1
            corrected_pos += 1

        return points
    
    def _rate(self, corrected_docs: Language, sentences_docs: Language) -> dict[str, int]:
        """
        Rates correctness of corrected sentences.
        """

        points: dict[str, int] = {"correct": 0, "incorrect": 0, "missing": 0}

        for corrected_doc, sentences_doc in zip(corrected_docs, sentences_docs):
            result = self._rate_sentence(corrected_doc, sentences_doc)
            points["correct"] += result["correct"]
            points["incorrect"] += result["incorrect"]
            points["missing"] += result["missing"]

        return points

    def run(self) -> dict[str, int]:
        # transform sentences to sentences without commas
        no_commas_sentences: list[str] = [sentence.replace(',', '') for sentence in self._sentences]

        # set sentence and sentence_doc in corrector
        self._corrector.sentences = no_commas_sentences

        # correct sentence and get result
        corrected_sentences: str = self._corrector.run()

        corrected_docs: Language = self._corrector.create_docs(
            corrected_sentences)
        sentences_doc = self._corrector.create_docs(self._sentences)

        # return rated result in format {'correct': int, 'incorrect': int, 'missing': int}
        return self._rate(corrected_docs, sentences_doc)



from ..test_comma_corrector import TestCommaCorrector


class TestJako(TestCommaCorrector):
    def test_jako(self):
        sentences = [
            "Pojechał tam jako przedstawiciel naszego kraju.",
            "Uważam, że jako rodzic mam decydujący głos w sprawie wychowania mojego syna.",
            "Przyszedłem tam jako pierwszy."
        ]

        self.assertSentences(sentences)

    def test_jako_wtr(self):
        sentences = [
            "Szkoła, jako placówka oświatowa, powinna znać edukacyjne potrzeby uczniów.",
            "Marek, jako nauczyciel, cieszył się sympatią wśród uczniów."
        ]

        self.assertSentences(sentences)

    def test_jako_przycz(self):
        sentences = [
            "Był ceniony, jako wybitny naukowiec.",
            "Jest bardzo popularny, jako gwiazda muzyki pop.",
            "Masz prawo do zasiłku, jako rodzic."
        ]

        self.assertSentences(sentences)

    def test_jako_że(self):
        sentences = [
            "Zadzwonił do niej, jako że nie przyszła dziś do szkoły.",
            "Poszła do lekarza, jako że źle się czuła."
        ]

        self.assertSentences(sentences)
    
    def test_jako_że_pocz(self):
        sentences = [
            "Jako że od miesiąca stosuję dietę, schudłam już pięć kilogramów.",
            "Jako że przez całe życie zajmowałam się tym zagadnieniem, wiem prawie wszystko na ten temat."
        ]

        self.assertSentences(sentences)
    
    def test_jako_że_wtr(self):
        sentences = [
            "Moja mama, jako że jest pielęgniarką, mogła zrobić mi ten zastrzyk.",
            "Ta książka, jako że jest kompleksowym opracowaniem, da ci odpowiedzi na wszystkie pytania."
        ]


from ..test_comma_corrector import TestCommaCorrector


class TestDlatego(TestCommaCorrector):
    def test_dlatego(self):
        sentences = [
            "Byłem zmęczony, dlatego zasnąłem bardzo wcześnie.",
            "W tym filmie gra moja ulubiona aktorka, dlatego chętnie go obejrzę.",
            "Mam mało pieniędzy, dlatego muszę oszczędzać."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestZanim(TestCommaCorrector):
    def test_zanim(self):
        sentences = [
            "Wyszłam, zanim wróciłeś do domu.",
            "Zrób zakupy, zanim pójdziesz do kina.",
            "Zdążyłem dobiec na przystanek, zanim odjechał autobus."
        ]

        self.assertSentences(sentences)

    def test_zanim_pocz(self):
        sentences = [
            "Zanim odpowiesz, zastanów się dobrze."
            "Zanim zdecyduję się na wyjazd, muszę złożyć wniosek o urlop."
        ]

        self.assertSentences(sentences)

    def test_zanim_wtr(self):
        sentences = [
            "Zawsze, zanim wyjdę z domu, sprawdzam, czy zamknęłam wszystkie okna."
            "Codziennie, zanim pójdę do pracy, biegam w pobliskim parku."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestAby(TestCommaCorrector):
    def test_aby_conj(self):
        sentences = [
            "Nastawiła budzik, aby wstać wcześnie.",
            "Aby wcześnie wstać, nastawiła budzik.",
            "Poszedł do sklepu, aby kupić słodycze.",
            "Nie mogła pozwolić sobie na to, aby wydać zbyt dużo pieniędzy."
        ]

        self.assertSentences(sentences)

    def test_tak_aby(self):
        sentences = [
            "Jechał szybko, tak aby zdążyli na samolot.",
            "Jechał tak, aby zdążyli na samolot.",
            "Mówiła szeptem, tak aby nikt nie usłyszał.",
            "Czytałam list wolno i dokładnie, tak aby niczego nie pominąć.",
            "Zrobiłam to tak, aby wszyscy byli zadowoleni.",
            "Powiedziałam to tak, aby usłyszał."
        ]

        self.assertSentences(sentences)

    def test_aby_part(self):
        sentences = [
            "Czy to aby działa?",
            "Czy to aby nie działa?"
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestAni(TestCommaCorrector):
    def test_ani(self):
        sentences = [
            "Nie chcę herbaty ani kawy.",
            "W moim domu nie ma telewizora ani radia."
        ]

        self.assertSentences(sentences)

    def test_ani_wtr(self):
        sentences = [
            "Nie przyszedł na umówione spotkanie, ani też nie zawiadomił nikogo.",
        ]

        self.assertSentences(sentences)

    def test_ani_powt(self):
        sentences = [
            "Nie mogłam ruszyć ani ręką, ani nogą.",
            "Ani nie pracowałem, ani nie odpocząłem."
        ]

        self.assertSentences(sentences)

    def test_ani_part(self):
        sentences = [
            "Nie miał ani grosza.",
            "Nie powiedziała ani słowa."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestSkoro(TestCommaCorrector):
    def test_skoro(self):
        sentences = [
            "Zrobię to, skoro tak nalegasz.",
            "Musiał dziwnie wyglądać, skoro wszyscy zwracali na niego uwagę.",
            "Jak mam im ufać, skoro zawiedli mnie już tyle razy."
        ]

        self.assertSentences(sentences)

    def test_skoro_pocz(self):
        sentences = [
            "Skoro nie możesz mi pomóc, to chociaż nie przeszkadzaj.",
            "Skoro nie zrozumiałaś, musiałam wyrazić się niezbyt jasno."
        ]

        self.assertSentences(sentences)

    def test_skoro_wtr(self):
        sentences = [
            "Postanowiłam, że pod koniec wakacji, skoro wtedy mam urlop, wybiorę się do Paryża.",
            "Iść z tobą do kina, skoro sobie tego nie życzysz, nie zamierzam."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestAlbo(TestCommaCorrector):
    def test_albo_powt(self):
        sentences = [
            "Albo pójdziemy do teatru, albo do kina.",
            "Wrócę do domu albo za godzinę, albo za dwie, albo za trzy."
        ]

        self.assertSentences(sentences)
    
    def test_albo_dopow(self):
        sentences = [
            "Był zawsze uczniem niezwykle zdolnym, albo raczej bardzo pilnym.",
            "Zwykle wykazywał się niesamowitą odwagą, albo raczej brawurą."
        ]

        self.assertSentences(sentences)
    

    def test_albo_wtr(self):
        sentences = [
            "Zwykle jestem bardzo ostrożna, albo raczej tchórzliwa, dlatego unikam niepewnych sytuacji."
        ]

        self.assertSentences(sentences)
    
    def test_albo_rown(self):
        sentences = [
            "Teraz albo nigdy.",
            "Kup ryż albo makaron.",
            "Wieczorami lubię czytać książki albo słuchać muzyki."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestŻe(TestCommaCorrector):
    def test_że(self):
        sentences = [
            "Powiedziała, że chce jak najszybciej skończyć pracę.",
            "Sytuacja była tak trudna, że nikt nie wiedział, jak z niej wybrnąć.",
            "Był bardzo głodny, mimo że zjadł kolację.",
            "Kupiłem ich tyle, że wystarczy dla całej rodziny.",
            "Mógłbym wyjechać za granicę, tyle że nie znam języków.",
            "Napisał, że kupi mleko oraz że umyje samochód.",
            "Nie powiedział, że mnie lubi ani że mnie nie lubi."
        ]

        self.assertSentences(sentences)

    def test_chyba_że(self):
        sentences = [
            "Nie zrobię tego, chyba że coś mi obiecasz.",
            "Wyślę ten list jeszcze dzisiaj, chyba że poczta będzie zamknięta.",
            "Pojedziemy jutro na plażę, chyba że będzie padać."
        ]

        self.assertSentences(sentences)

    def test_mimo_że(self):
        sentences = [
            "Nie byłam głodna, mimo że nic dziś nie jadłam.",
            "Przyjęcie się udało, mimo że nie wszyscy goście dotarli.",
        ]

        self.assertSentences(sentences)

    def test_mimoże_pocz(self):
        sentences = [
            "Mimo że dbam o swoje zdrowie, ciągle źle się czuję."
        ]

        self.assertSentences(sentences)

    def test_mimo_że_wtr(self):
        sentences = [
            "Znów, mimo że dużo się uczyłam, nie zdałam egzaminu."
        ]

        self.assertSentences(sentences)

    def test_z_tym_że(self):
        sentences = [
            "Zacznę dziś czytać tę książkę, z tym że dopiero wieczorem.",
            "Przygotuję dziś kolację, z tym że bez mięsa.",
            "Zgodzę się na to, z tym że mam jeden warunek."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestChoć(TestCommaCorrector):
    def test_choć_conj(self):
        sentences = [
            "Uprawiał sport, choć był niepełnosprawny.",
            "Poszła tam, choć nie powinna."
        ]

        self.assertSentences(sentences)
    
    def test_choć_conj_pocz(self):
        sentences = [
            "Choć jestem przeziębiony, muszę iść do pracy.",
            "Choć nie jestem o tym przekonany, zrobię to."
        ]

        self.assertSentences(sentences)
    
    def test_choć_part(self):
        sentences = [
            "Zrób choć zakupy.",
            "Powinieneś choć przeprosić."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestTo(TestCommaCorrector):
    def test_to(self):
        sentences = [
            "Chcesz, to idź tam.",
            "Podaj telefon, to zadzwonię do niego.",
            "Opuszczałeś lekcje, to masz teraz zaległości."
        ]

        self.assertSentences(sentences)

    def test_to_compl(self):
        sentences = [
            "Jeśli chcesz, to zostań tutaj.",
            "Skoro tak bardzo ci na niej zależy, to zaproś ją do kina.",
            "Gdyby przyszła punktualnie, to nic by się nie stało."
        ]

        self.assertSentences(sentences)

    def test_to_join(self):
        sentences = [
            "Do ciasta dodaj przyprawy korzenne, to jest cynamon, goździki, kardamon i anyż.",
            "Zrobię to potem, to znaczy kiedy odrobię lekcje."
        ]

        self.assertSentences(sentences)

    def test_to_conn(self):
        sentences = [
            "Zakopane to zimowa stolica Polski.",
            "Warzywa to źródło wielu cennych witamin.",
            "Właściwie to nic na temat nie wiem."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestLecz(TestCommaCorrector):
    def test_lecz(self):
        sentences = [
            "Zawsze byłam optymistką, lecz ostatnio mam czarne myśli.",
            "Nie jestem strachliwy, lecz rozsądny.",
            "Chciałam iść na spacer, lecz pogoda nie sprzyjała przechadzkom."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestCzyli(TestCommaCorrector):
    def test_czyli(self):
        sentences = [
            "Przyjdę do ciebie po lekcjach, czyli około piętnastej.",
            "Osobom niepełnosprawnym zaleca się felinoterapię, czyli metodę terapii polegającą na kontakcie z kotem."
        ]

        self.assertSentences(sentences)
    
    def test_czyli_wtr(self):
        sentences = [
            "Wiek pary i elektryczności, czyli wiek XIX, oznaczał wielką rewolucję przemysłową.",
            "FE, czyli żelazo, to pierwiastek chemiczny o liczbie atomowej 26."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestGdy(TestCommaCorrector):
    def test_gdy(self):
        sentences = [
            "Było południe, gdy się obudziłem.",
            "Nie lubię, gdy się tak zachowujesz.",
            "Skończyłam studia, gdy miałam dwadzieścia pięć lat."
        ]

        self.assertSentences(sentences)

    def test_gdy_pocz(self):
        sentences = [
            "Gdy wracałam do domu, zerwał się silny wiatr.",
            "Gdy w końcu się spotkamy, wszystko dokładnie ci opowiem."
        ]

        self.assertSentences(sentences)

    def test_gdy_join(self):
        sentences = [
            "Zrozumiałam to, dopiero gdy sama tego doświadczyłam.",
            "Śpisz, podczas gdy powinieneś być już dawno w pracy."
        ]

        self.assertSentences(sentences)

    def test_zwłaszcza_gdy(self):
        sentences = [
            "Powinieneś pić dużo wody, zwłaszcza gdy jest gorąco.",
            "Lubię na nią patrzeć, zwłaszcza gdy się uśmiecha.",
            "Bywał niemiły, zwłaszcza gdy nie czuł się zbyt dobrze."
        ]

        self.assertSentences(sentences)

    def test_w_przypadku_gdy(self):
        sentences = [
            "Zrobię to, w przypadku gdy nie będzie innego wyjścia.",
        ]

        self.assertSentences(sentences)

    def test_w_przypadku_gdy_pocz(self):
        sentences = [
            "W przypadku gdy wszyscy zachorujemy, nasz wyjazd trzeba będzie przełożyć."
        ]

        self.assertSentences(sentences)

    def test_w_sytuacji_gdy(self):
        sentences = [
            "Należy przeprowadzić operację, w sytuacji gdy życie pacjenta jest zagrożone."
        ]

        self.assertSentences(sentences)

    def test_w_sytuacji_gdy_pocz(self):
        sentences = [
            "W sytuacji gdy nie dojdziemy do porozumienia, nasza dalsza współpraca nie będzie możliwa."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestBo(TestCommaCorrector):
    def test_bo(self):
        sentences = [
            "Zostaniemy dziś w domu, bo na dworze jest bardzo zimno.",
            "Wiem, bo czytałem o tym w gazecie.",
            "Załóż czapkę, bo zmarzniesz.",
            "Te informacje są dla nas nieprzydatne, bo nieaktualne.",
            "Drogie, bo drogie, ale jakie piękne."
        ]

        self.assertSentences(sentences)


from . import rules
from spacy import load, Language
import re


class CommaCorrector:
    """
    Corrects punctuation in given sentences.
    """

    def __init__(self, sentences: list[str] = []) -> None:
        self._nlp: Language = load("pl_core_news_sm")

        self._sentences: list[str] = sentences
        self._sentences_docs: list[Language] = self.create_docs(
            self._sentences)

        # get all rules from rules.py
        self._rules: dict = {rule[6:]: getattr(rules, rule) for rule in dir(
            rules) if rule.startswith('check_')}

        # get all keys from rules dict
        self._rules_keys: list[str] = [key for key in self._rules.keys()]

    @property
    def sentences(self) -> list[str]:
        return self._sentences

    @sentences.setter
    def sentences(self, sentences: list[str]) -> None:
        self._sentences = sentences
        self._sentences_docs = self.create_docs(self._sentences)

    @property
    def sentences_docs(self) -> list[Language]:
        return self._sentences_docs

    def create_docs(self, sentences: list[str]) -> list[Language]:
        """Creates spaCy documents from given sentences."""
        return self._nlp.pipe(sentences)

    @staticmethod
    def _join_sentence(sentence: list[str]) -> str:
        """Joins list of words into sentence. Removes spaces before punctuation marks."""
        sentence = ' '.join(sentence)

        sentence = re.sub(r' ([.,?!:;])', r'\1', sentence)

        return sentence

    def _correct_sentence(self, sentence_doc) -> str:
        """
        Corrects punctuation in given sentence.

        Returns:
            str: Corrected sentence.
        """

        # transform spaCy document into list of words
        sentence_text: list[str] = [
            token.text for token in sentence_doc]

        # shift is used to correct index of token in sentence, if comma was inserted
        shift: int = 0

        # occured is used to check if rule was already used. Used to check for enumeration.
        occured: dict[str, bool] = {key: False for key in self._rules_keys}

        # iterate over all tokens in sentence
        for token in sentence_doc:
            index = token.i

            # skip first token, because it will never have a comma before it
            if index == 0:
                continue

            # skip if token is not in rules, because it is (probably) not a word, that can have comma before it
            if token.text not in self._rules_keys:
                continue

            # get result of rule check in format {'insert': bool, 'insert_pos': int, 'occured': bool}
            result = self._rules[token.text](
                token, sentence_doc[index - 1], occured[token.text])

            # set occured to True, if rule was used and it's possible to be an enumeration
            occured[token.text] = result['occured']

            # skip if comma should not be inserted
            if not result['insert']:
                continue

            # check if token at position index + result['insert_pos'] is not a punctuation mark
            if sentence_text[index + result['insert_pos'] + shift - 1] == ',':
                continue

            # insert comma result['insert_pos'] characters before token
            sentence_text.insert(index + result['insert_pos'], ',')

            # increase shift by 1, because comma was inserted
            shift += 1

        return self._join_sentence(sentence_text)

    def run(self):
        """Corrects punctuation in all sentences."""

        if self._sentences == []:
            raise Exception('No sentences were given.')

        if self._sentences_docs == []:
            raise Exception('No sentences docs were created.')

        return [self._correct_sentence(sentence_doc) for sentence_doc in self._sentences_docs]



from ..test_comma_corrector import TestCommaCorrector


class TestAż(TestCommaCorrector):
    def test_aż_conj(self):
        sentences = [
            "Długo milczał, aż nagle krzyknął.",
            "Szłam wolno, aż w końcu przyspieszyłam kroku.",
            "Ćwiczyłem tak długo, aż się zmęczyłem.",
            "Prowadziła zbiórkę, aż zebrała potrzebną kwotę."
        ]

        self.assertSentences(sentences)

    def test_aż_part(self):
        sentences = [
            "Zjadł aż pięć kawałków tortu.",
            "Spałam dziś aż do południa."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestDopóki(TestCommaCorrector):
    def test_dopóki(self):
        sentences = [
            "Biegłem, dopóki nie poczułem zmęczenia.",
            "Nie przyjdę do szkoły, dopóki będę chory."
        ]

        self.assertSentences(sentences)
    
    def test_dopóki_pocz(self):
        sentences = [
            "Dopóki trwały wakacje, byliśmy szczęśliwi.",
            "Dopóki tu mieszkam, nie pozwolę na to."
        ]

        self.assertSentences(sentences)
    
    def test_dopóki_wtr(self):
        sentences = [
            "Tak długo, dopóki na morzu był sztorm, musieliśmy czekać cierpliwie w porcie."
        ]

        self.assertSentences(sentences)
    

    def test_dopóki_dopóty(self):
        sentences = [
            "Dopóki był upał, dopóty nie wychodziłem z domu.",
            "Dopóty nie wychodziłem z domu, dopóki był upał."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestCzy(TestCommaCorrector):
    def test_czy_conj(self):
        sentences = [
            "Zjesz cukierka czy ciastko?",
            "Idziesz pobiegać czy chcesz odpocząć?",
            "Najczęściej gościmy u nas turystów z Niemiec, Austrii czy Turcji.",
            "To był Adam czy Marcin, czy Andrzej?",
            "Było to chyba we wtorek, czy może w środę, naprawdę nie pamiętam.",
            "Kupiła dwie sukienki, chyba zieloną i pomarańczową, czy coś w tym stylu."
        ]

        self.assertSentences(sentences)

    def test_czy_part(self):
        sentences = [
            "Nie wiem, czy to zrobił.",
            "Musimy najpierw ustalić, czy to w ogóle możliwe.",
            "Tak naprawdę nie wiadomo, czy była tam tego dnia.",
            "Od tego, czy sprzedamy wystarczającą ilość towaru, zależy nasza przyszłość.",
            "Asia pytała, czy napijecie się kawy czy herbaty.",
            "Nie wiedział, czy może poczęstować się cukierkami, czy nie."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestKtóry(TestCommaCorrector):
    def test_który(self):
        sentences = [
            "Nie wiem, który z was mówi prawdę.",
            "Podaj mi tę książkę, która leży na biurku."
        ]

        self.assertSentences(sentences)

    def test_który_pocz(self):
        sentences = [
            "Który z nich jest godny zaufania, naprawdę nie wiem."
        ]

        self.assertSentences(sentences)

    def test_który_wtr(self):
        sentences = [
            "Obraz, który widzimy, pochodzi z XVIII wieku.",
            "Ta kobieta, którą spotkałam, powiedziała mi, że wszystko jest w porządku."
        ]

        self.assertSentences(sentences)

    def test_który_join(self):
        sentences = [
            "To jest dom, w którym się wychowałam.",
            "Marek to człowiek, na którego można liczyć.",
            "Byłam ostatnio koncercie, podczas którego włączył się alarm przeciwpożarowy."
        ]

        self.assertSentences(sentences)

    def test_który_powt(self):
        sentences = [
            "Znałam kobietę, która uwielbiała koty i która miała ich w domu aż osiem.",
            "To jest dom, który jest w bardzo dobrym stanie i który nie wymaga remontu."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestZatem(TestCommaCorrector):
    def test_zatem(self):
        sentences = [
            "Odrobiłam lekcje, zatem teraz mogę odpocząć."
        ]

        self.assertSentences(sentences)

    def test_zatem_mid(self):
        sentences = [
            "Wszystko jest gotowe, możemy zatem zaczynać.",
            "Mam ochotę obejrzeć film, pójdę zatem do kina."
        ]

        self.assertSentences(sentences)

    def test_zatem_poprz(self):
        sentences = [
            "Musimy zatem jechać.",
            "Pójdę zatem do sklepu."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestOraz(TestCommaCorrector):
    def test_oraz_conj(self):
        sentences = [
            "Zjem zupę oraz drugie danie."
        ]

        self.assertSentences(sentences)

    def test_oraz_other(self):
        sentences = [
            "Byli tam Piotrek, Agnieszka oraz Wojtek, oraz Maciej.",
            "Byli tam Piotrek oraz Agnieszka oraz Wojtek oraz Maciej."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestJeżeli(TestCommaCorrector):
    def test_jeżeli(self):
        sentences = [
            "Pójdziemy na spacer, jeżeli będzie ładna pogoda."
        ]

        self.assertSentences(sentences)
    
    def test_jeżeli_pocz(self):
        sentences = [
            "Jeżeli nie zdam tego egzaminu, będę musiał znów się uczyć."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestChociaż(TestCommaCorrector):
    def test_chociaż(self):
        sentences = [
            "Zdał egzamin, chociaż w ogóle się nie uczył.",
            "Muszę tam iść, chociaż nie mam na to ochoty."
        ]

        self.assertSentences(sentences)
    
    def test_chociaż_pocz(self):
        sentences = [
            "Chociaż jestem chory, pójdę dziś do pracy.",
            "Chociaż wciąż jest zima, robi się coraz cieplej."
        ]

        self.assertSentences(sentences)
    
    def test_chociaż_part(self):
        sentences = [
            "Mogłaś chociaż przeprosić.",
            "Daj mi chociaż dzisiaj spokój."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestBądź(TestCommaCorrector):
    def test_bądź(self):
        sentences = [
            "Przyjadę do ciebie tramwajem bądź autobusem.",
            "Latem wyjadę nad morze bądź zostanę w domu."
        ]

        self.assertSentences(sentences)

    def test_bądź_join(self):
        sentences = [
            "Dokumenty proszę dostarczyć osobiście bądź też przesłać listownie."
        ]

        self.assertSentences(sentences)

    def test_bądź_powt(self):
        sentences = [
            "Na deser podam bądź lody, bądź ciasto.",
            "Egzamin można zdawać bądź ustnie, bądź pisemnie."
        ]

        self.assertSentences(sentences)

    def test_bądź_part(self):
        sentences = [
            "Połóż to gdzie bądź.",
            "Zawołaj kogo bądź."
        ]

        self.assertSentences(sentences)

    def test_bądź_co_bądź(self):
        sentences = [
            "To twój bądź co bądź ojciec."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestTakże(TestCommaCorrector):
    def test_także(self):
        sentences = [
            "Ona także się boi.",
            "W naszym sklepie sprzedajemy także wyroby innych producentów."
        ]

        self.assertSentences(sentences)

    def test_także_dop(self):
        sentences = [
            "Nie tylko nauczyciele, także uczniowie mają swoje prawa i obowiązki.",
            "Szyła ubrania, zajmowała się także ich sprzedażą."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestNatomiast(TestCommaCorrector):
    def test_natomiast(self):
        sentences = [
            "Nie mam ochoty na lody, natomiast z przyjemnością zjem kawałek tortu.",
            "Wczoraj czułam się dobrze, natomiast dzisiaj nie mam na nic siły."
        ]

        self.assertSentences(sentences)
    
    def test_natomiast_poprz(self):
        sentences = [
            "My natomiast musimy ustalić plan działania.",
            "Mam natomiast inną prośbę."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestAle(TestCommaCorrector):
    def test_ale_conj(self):
        sentences = [
            "Zrobiła to, ale niedokładnie.",
            "To było pyszne, ale bardzo niezdrowe.",
            "Zarabiał niewiele, ale był bardzo oszczędny.",
            "Wprawdzie nie protestowała, ale zgodziła się niechętnie."
        ]

        self.assertSentences(sentences)

    def test_ale_part(self):
        sentences = [
            "Zobacz, ale samochód!",
            "Ale heca!",
            "Dostałem prezent, ale jaki!"
        ]

        self.assertSentences(sentences)

    def test_ale_excl(self):
        sentences = [
            "Ale, ale, my tu się dobrze bawimy, a oni czekają.",
            "Ale, ale, czy już jej powiedziałeś?"
        ]

        self.assertSentences(sentences)

    def test_ale_noun(self):
        sentences = [
            "Ona zwykle ma jakieś ale.",
            "To jest świetne, jest tylko jedno ale."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestŻeby(TestCommaCorrector):
    def test_żeby(self):
        sentences = [
            "Muszę dużo się uczyć, żeby zdać egzaminy.",
            "Chcę wyjechać, żeby odpocząć.",
            "Jesteś zbyt dumny, żeby o to poprosić.",
            "Podjęła tę pracę, żeby tylko zarobić pieniądze."
        ]

        self.assertSentences(sentences)
    
    def test_żeby_pocz(self):
        sentences = [
            "Żeby odpocząć, muszę wyjechać.",
            "Żeby wygrać nagrodę, trzeba wziąć udział w konkursie."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestStąd(TestCommaCorrector):
    def test_stąd_conj(self):
        sentences = [
            "Często opuszczał lekcje, stąd miał duże kłopoty w nauce.",
            "Jestem chory, stąd musiałem dziś zostać w domu."
        ]

        self.assertSentences(sentences)

    def test_stąd_poj(self):
        sentences = [
            "Jak się stąd wyrwać?",
            "Nie oddalaj się stąd.",
            "Zabierz stąd dzieci."
        ]

        self.assertSentences(sentences)
    
    def test_stąd_od_tego(self):
        sentences = [
            "Zaczął opuszczać lekcje, stąd już tylko krok do kłopotów w nauce.",
            "Mój pies ma puszystą sierść, stąd jego imię Puszek."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestBy(TestCommaCorrector):
    def test_by(self):
        sentences = [
            "Uczył się dużo, by zdać egzamin.",
            "Marzę o tym, by znów tam pojechać."
        ]

        self.assertSentences(sentences)
    
    def test_by_pocz(self):
        sentences = [
            "By zdążyć dzisiaj do pracy, jechałem szybciej niż zwykle.",
            "By schudnąć, przeszłam na restrykcyjną dietę."
        ]

        self.assertSentences(sentences)
    
    def test_by_wtr(self):
        sentences = [
            "Nauczyciel prosił, by tego nie robili, wszystkich uczniów."
        ]

        self.assertSentences(sentences)
    
    def test_by_join(self):
        sentences = [
            "To była lekkomyślność, by nie powiedzieć głupota.",
            "Był znany z odwagi, by nie rzec brawury."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestLub(TestCommaCorrector):
    def test_lub_conj(self):
        sentences = [
            "Jutro Adam pojedzie na zakupy lub umyje samochód.",
            "Tę książkę Marcin wypożyczył z biblioteki lub kupił w antykwariacie."
        ]

        self.assertSentences(sentences)

    def test_lub_poj(self):
        sentences = [
            "Do cioci pojedziemy we wtorek lub w środę."
        ]

        self.assertSentences(sentences)

    def test_lub_powt(self):
        sentences = [
            "Jutro Adam pojedzie na zakupy lub umyje samochód, lub ugotuje obiad."
        ]

        self.assertSentences(sentences)

    def test_lub_dopow(self):
        sentences = [
            "Na obiad zjemy zupę, którą przywiezie ciocia, lub zamówimy coś z restauracji.",
            "Był człowiekiem trudnym w obejściu, lub raczej niesympatycznym."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestNiż(TestCommaCorrector):
    def test_niż_podrz(self):
        sentences = [
            "Jest gorzej, niż sądziłem.",
            "Dał nam więcej, niż wcześniej obiecywał.",
            "To kosztowało mniej, niż się spodziewałam."
        ]

        self.assertSentences(sentences)

    def test_niż_bezok(self):
        sentences = [
            "Wolę poczekać, niż stracić tę szansę.",
            "Łatwiej jest powiedzieć, niż zrobić."
        ]

        self.assertSentences(sentences)

    def test_niż_porown(self):
        sentences = [
            "Małgosia jest ładniejsza niż jej siostra.",
            "Lepszy wróbel w garści niż gołąb na dachu."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestCo(TestCommaCorrector):
    def test_co_wpro(self):
        sentences = [
            "Zapomniałam, co mówiłeś wczoraj.",
            "Robił, co chciał."
        ]

        self.assertSentences(sentences)
    
    def test_co_przed_orz(self):
        sentences = [
            "To, co jest dobre dla ciebie, nie musi być odpowiednie dla mnie.",
            "Dobra książka to coś, co lubię najbardziej.",
            "Chcę ci życzyć wszystkiego, co najlepsze."
        ]

        self.assertSentences(sentences)
    
    def test_co_okol(self):
        sentences = [
            "Nie mam co robić.",
            "U nich w domu nie było co jeść."
        ]

        self.assertSentences(sentences)
    
    def test_co_part(self):
        sentences = [
            "Opuszczał lekcje co najmniej raz w tygodniu.",
            "Do kina chodzę średnio co miesiąc."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestJeśli(TestCommaCorrector):
    def test_jeśli(self):
        sentences = [
            "Zadzwonię do ciebie, jeśli tylko będę mogła.",
            "Zrobię to, jeśli coś mi obiecasz."
        ]

        self.assertSentences(sentences)
    
    def test_jeśli_pocz(self):
        sentences = [
            "Jeśli się nie myślę, jutro masz urodziny.",
            "Jeśli opowiesz mi o wszystkim, postaram się to zrozumieć."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestJednak(TestCommaCorrector):
    def test_jednak_conj(self):
        sentences = [
            "Na miejsce przyjechała karetka pogotowia, jednak było już za późno.",
            "Obiecał dochować tajemnicy, jednak wszystko im powiedział."
        ]

        self.assertSentences(sentences)
    
    def test_jednak_pocz(self):
        sentences = [
            "Było bardzo zimno, postanowiliśmy jednak iść na spacer.",
            "Pracowałem ciężko, ciągle jednak brakowało mi pieniędzy."
        ]

        self.assertSentences(sentences)

    def test_jednak_part(self):
        sentences = [
            "Miałeś jednak rację.",
            "Kłamstwo jednak zawsze wyjdzie na jaw."
        ]

        self.assertSentences(sentences)



from ..test_comma_corrector import TestCommaCorrector


class TestGdyż(TestCommaCorrector):
    def test_gdyż(self):
        sentences = [
            "Nie mogę z tobą jechać, gdyż jestem chora.",
            "Milczał, gdyż nie miał już nic do powiedzenia."
        ]

        self.assertSentences(sentences)


from ..test_comma_corrector import TestCommaCorrector


class TestKiedy(TestCommaCorrector):
    def test_kiedy(self):
        sentences = [
            "Nie wiem, kiedy to się stało.",
            "Przychodź do mnie, kiedy tylko chcesz."
        ]

        self.assertSentences(sentences)

    def test_kiedy_pocz(self):
        sentences = [
            "Kiedy wracałam do domu, spadł deszcz.",
            "Kiedy dzwoniłeś, byłam w łazience."
        ]

        self.assertSentences(sentences)
    
    def test_kiedy_wtr(self):
        sentences = [
            "We wtorek, kiedy szłam do pracy, spotkałam Marka.",
            "Teraz, kiedy są wakacje, nie muszę wstawać o świcie."
        ]

        self.assertSentences(sentences)